#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
# @Version     : Python 3.11.4
# @Software    : Sublime Text 4
# @Author      : StudentCWZ
# @Email       : StudentCWZ@outlook.com
# @Date        : 2023/11/7 16:16
# @File        : task.py
# @Description :
"""

# Import built-in modules
import datetime

# Import custom modules
from application.dao import LogDao
from application.extensions.init_sqlalchemy import db


def task():
    """
    Execute some tasks.

    This function defines a task to parse logs between two specific datetime points.
    The task uses the application's database context and configurations for the Elasticsearch index
    and an additional database.

    It uses the `parse` method from `LogDao` to process the logs.

    Note: The start and end dates are hardcoded in this example.

    Returns:
        None
    """
    # You can uncomment the following lines to use the current date and time and the previous day's date and time
    end_stamp = datetime.datetime.now()
    start_stamp = end_stamp - datetime.timedelta(days=1)
    start = start_stamp.strftime('%Y-%m-%d %H:%M:%S')
    end = end_stamp.strftime('%Y-%m-%d %H:%M:%S')

    # Here the start and end dates are hardcoded
    # start = "2021-11-08 00:00:00"
    # end = "2021-11-09 00:00:00"

    # Use the application's database context
    with db.app.app_context():
        # Get the Elasticsearch index from the application's configuration
        index = db.app.config.Elasticsearch.Index

        # Get the ExtraDB configuration from the application's configuration
        cfg = db.app.config.ExtraDB

        # Create a dictionary of options for the additional database
        options = {
            "host": cfg.Host,
            "user": cfg.User,
            "password": cfg.Password,
            "database": cfg.DB,
            "port": cfg.Port,
        }

        # Get the SQL query from the ExtraDB configuration
        sql = cfg.Sql

        # Call the parse method from LogDao with the necessary parameters
        LogDao.parse(start, end, index, sql, options)

